==> pkg_add_it-1.3.tar.gz: pkg_add_it-1.3/main.h <==
/*-
 * Copyright (c) 2010  Marin Atanasov Nikolov  <dnaeon@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef _MAIN_H_
#define _MAIN_H_

#ifndef _ERR_H_
#include <err.h>
#endif

#define ERRX			 errx(1, "Error in %s() from %s at line %d", __func__, __FILE__, __LINE__)
#define WARNX			 warnx("Warning in %s() from %s at line %d", __func__, __FILE__, __LINE__)

#define PROGNAME		 "pkg_add_it"
#define PROGVERS		 "1.3"
#define PROGDESC		 "pkg_add interactive tool"

/* flags used to check the specified command-line options */
#define OPTION_VALID_OPTS        0x00000001
#define OPTION_PAGER		 0x00000002
#define OPTION_ALTERNATIVE_INDEX 0x00000004
#define OPTION_ALTERNATIVE_FILE  0x00000008
#define OPTION_DRY_RUN           0x00000010
#define OPTION_REMOTE_INSTALL    0x00000020
#define OPTION_LOCAL_INSTALL     0x00000040
#define OPTION_SHOW_DEPS	 0x00000080
#define OPTION_SHOW_CATS	 0x00000100
#define OPTION_REGEX		 0x00000200
#define OPTION_REGEX_EXTENDED	 0x00000400

/* valid command line arguments */
#define CL_ARGS			 "hnpxXCi:f:l:r:D:"

int yesno_prompt(const char *prompt);

#endif /* !_MAIN_H_ */

==> pkg_add_it-1.3.2.tar.gz: pkg_add_it-1.3.2/main.h <==
/*-
 * Copyright (c) 2010  Marin Atanasov Nikolov  <dnaeon@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#ifndef _MAIN_H_
#define _MAIN_H_

#ifndef _SYS_PARAM_H_
#include <sys/param.h>
#endif

#ifndef _ERR_H_
#include <err.h>
#endif

/*
 * FreeBSD versions prior to 7.2 does not have strndup() function
 * FreeBSD versions prior to 8.0 does not have strnlen() function
 *
 * Here we define macro functions to use the standard strdup() and
 * strlen() functions where needed, else we use the strnXXX() ones.
 */

#if __FreeBSD_version < 702000
#define STRNDUP(str,len)	 strdup(str)
#define STRNLEN(str,len)	 strlen(str) 
#elif __FreeBSD_version >= 800505
#define STRNDUP(str,len)	 strndup(str,len)
#define STRNLEN(str,len)	 strnlen(str,len)
#elif __FreeBSD_version >= 702000
#define STRNDUP(str,len)	 strndup(str,len)
#define STRNLEN(str,len)	 strlen(str)
#endif

#define ERRX			 errx(1, "Error in %s() from %s at line %d", __func__, __FILE__, __LINE__)
#define WARNX			 warnx("Warning in %s() from %s at line %d", __func__, __FILE__, __LINE__)

#define PROGNAME		 "pkg_add_it"
#define PROGVERS		 "1.3.2"
#define PROGDESC		 "tool for interactive installation of packages"

/* flags used to check the specified command-line options */
#define OPTION_VALID_OPTS	 0x00000001
#define OPTION_PAGER		 0x00000002
#define OPTION_ALTERNATIVE_INDEX 0x00000004
#define OPTION_ALTERNATIVE_FILE	 0x00000008
#define OPTION_DRY_RUN		 0x00000010
#define OPTION_REMOTE_INSTALL	 0x00000020
#define OPTION_LOCAL_INSTALL	 0x00000040
#define OPTION_SHOW_DEPS	 0x00000080
#define OPTION_SHOW_CATS	 0x00000100
#define OPTION_REGEX		 0x00000200
#define OPTION_REGEX_EXTENDED	 0x00000400

/* valid command line arguments */
#define CL_ARGS			 "hnpxXCi:f:l:r:D:"

int yesno_prompt(const char *prompt);

#endif /* !_MAIN_H_ */
